Calculator class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
double a, double b) → double - Adds two numbers.
-
divide(
double a, double b) → double -
Divides two numbers.
Throws ArgumentError if
bis zero. -
multiply(
double a, double b) → double - Multiplies two numbers.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subtract(
double a, double b) → double - Subtracts two numbers.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited